format_attempt_notes

Function format_attempt_notes 

pub fn format_attempt_notes(unit: &Unit) -> Option<String>
Format the attempt_log and notes field into a combined notes string.

Returns None if there are no attempt notes and no unit notes.