pub fn create(
mana_dir: &Path,
params: CreateParams,
) -> Result<CreateResult, Error>Expand description
Create a new unit and persist it to disk.
pub fn create(
mana_dir: &Path,
params: CreateParams,
) -> Result<CreateResult, Error>Create a new unit and persist it to disk.