pub fn list(
mana_dir: &Path,
params: &ListParams,
) -> Result<Vec<IndexEntry>, Error>Expand description
Load the index, apply filters, and return matching entries.
pub fn list(
mana_dir: &Path,
params: &ListParams,
) -> Result<Vec<IndexEntry>, Error>Load the index, apply filters, and return matching entries.