pub struct RunWave {
pub units: Vec<ReadyUnit>,
}Expand description
A wave of units that can run concurrently (no inter-wave dependencies).
Fields
units: Vec<ReadyUnit>Units in this wave, sorted by priority then critical-path weight.