Module verify

Module verify 

Structs

VerifyResult
Result of running a verify command.

Functions

run_verify
Run the verify command for a unit without closing it.
run_verify_command
Execute a verify command in the given directory with an optional timeout.