Module blocking

Module blocking 

Enums

BlockReason
Why a unit cannot be dispatched right now.
ScopeWarning
Soft scope warnings — displayed but don’t block dispatch.

Constants

MAX_PATHS
Maximum number of paths before a unit is considered oversized.
MAX_PRODUCES
Maximum number of produces artifacts before a unit is considered oversized.

Functions

check_blocked
Check whether entry is blocked, returning the reason if so.
check_blocked_with_archive
Like check_blocked, but also checks the archive index. Archived units are treated as closed (satisfied).
check_scope_warning
Check for scope warnings (non-blocking).