check_blocked

Function check_blocked 

pub fn check_blocked(entry: &IndexEntry, index: &Index) -> Option<BlockReason>
Check whether entry is blocked, returning the reason if so.

Checks in priority order:

  1. Explicit dependencies — any dep that isn’t closed (or doesn’t exist).
  2. Requires/produces — sibling units that produce a required artifact but aren’t closed yet.

Note: This overload does not check archived units. If a dependency was closed and archived, it will appear unsatisfied. Use check_blocked_with_archive when archive awareness is needed (e.g., mana run).