Module hooks

Module hooks 

Structs

HookPayload
HookVars
Template variables for config hook expansion.

Enums

HookEvent

Functions

create_trust
Enable hook trust by creating the .mana/.hooks-trusted file.
current_git_branch
Get the current git branch name, or None if not in a git repo.
execute_config_hook
Execute a config-based hook command asynchronously.
execute_hook
Execute a hook script with the given payload.
expand_template
Expand template variables in a hook command string.
get_hook_path
Get the path to a hook script based on the event and project directory.
is_hook_executable
Check if a hook file exists and is executable.
is_trusted
Check if hooks are trusted (enabled).
revoke_trust
Revoke hook trust by deleting the .mana/.hooks-trusted file.