Git worktree detection and merge utilities.
This module provides functions to detect if the current directory is within a git worktree, and to merge changes back to the main branch.
Structs
- Worktree
Info - Information about a git worktree.
Enums
- Merge
Result - Result of a merge operation.
Functions
- cleanup_
worktree - Clean up a worktree and its branch.
- commit_
worktree_ changes - Commit all changes in the specified worktree directory.
- detect_
worktree - Detect if the given directory is within a git worktree.
- merge_
to_ main - Merge the worktree branch to main.