Structs
- Create
Args - Create arguments structure for organizing all the parameters passed to create.
Functions
- assign_
child_ id - Assign a child ID for a parent unit. Scans .mana/ for {parent_id}.{N}-*.md, finds highest N, returns “{parent_id}.{N+1}”.
- cmd_
create - Create a new unit.
- cmd_
create_ next - Create a new unit that automatically depends on @latest (the most recently updated unit).
- parse_
on_ fail