pub struct GlobalConfig {
pub user: Option<String>,
pub user_email: Option<String>,
}Expand description
Minimal global config stored at ~/.config/mana/config.yaml.
Only holds user identity fields — project-level config has everything else.
Fields
user: Option<String>user_email: Option<String>Implementations
Sourceimpl GlobalConfig
impl GlobalConfig
Sourcepub fn path() -> Result<PathBuf, Error>
pub fn path() -> Result<PathBuf, Error>
Path to the new global config file: ~/.config/mana/config.yaml.
Sourcepub fn load() -> Result<GlobalConfig, Error>
pub fn load() -> Result<GlobalConfig, Error>
Load global config. Returns Default if file doesn’t exist.
Falls back to the legacy units config directory if the new path doesn’t exist
but the old one does, to support migration from the old location.