Structs
- Hook
Payload - Hook
Vars - Template variables for config hook expansion.
Enums
Functions
- create_
trust - Enable hook trust by creating the .mana/.hooks-trusted file.
- current_
git_ branch - Get the current git branch name, or None if not in a git repo.
- execute_
config_ hook - Execute a config-based hook command asynchronously.
- execute_
hook - Execute a hook script with the given payload.
- expand_
template - Expand template variables in a hook command string.
- get_
hook_ path - Get the path to a hook script based on the event and project directory.
- is_
hook_ executable - Check if a hook file exists and is executable.
- is_
trusted - Check if hooks are trusted (enabled).
- revoke_
trust - Revoke hook trust by deleting the .mana/.hooks-trusted file.